Item

Struct Item 

pub struct Item<T = usize> { /* private fields */ }
Queue item.

Items are stored in queues, and can have arbitrary associated data. An item has a specific deadline, which is the ordering property of the queue.

Items must only be considered for processing when their deadline has passed, which is exactly what Queue::take ensures. This allows to implement timers and intervals in an efficient manner. In case two items have the same deadline, order is undefined, but this doesn’t matter for us.

Note that mutable data needs to be stored outside of the queue, as items are immutable. The built-in Queue uses a Slab for this matter.

Implementations

Source

impl<T> Item<T>

pub fn new(data: T) -> Self

Creates a queue item.

Examples
use zrx_store::queue::Item;

// Create queue item
let item = Item::new(42);
pub fn set_deadline(&mut self, deadline: Instant)

Updates the deadline of the queue item.

Examples
use std::time::Instant;
use zrx_store::queue::Item;

// Create queue item and set deadline
let mut item = Item::new(42);
item.set_deadline(Instant::now());
Source

impl<T> Item<T>

pub fn deadline(&self) -> Instant

Returns the deadline.

pub fn data(&self) -> &T

Returns a reference to the associated data.