Queue

Struct Queue 

pub struct Queue<K, V, S = HashMap<K, Item>> { /* private fields */ }
Queue.

This is a specialization of Store, more specifically Ordered, that maintains insertion order and allows to assign specific deadlines to items. Values themselves don’t need to implement Ord, since the ordering is completely independent and induced by the queue.

When an item is inserted, it is annotated with Instant::now, which on the one hand implements insertion order, and on the other hand allows to change the ordering of an item through Queue::set_deadline. This allows to remove items from visibility until a certain point in time.

Additionally, Queue is not a queue in the traditional sense, since it adds queueing to a Store, an immutable collection of key-value pairs. The queue is self-organizing, and iterating over it will always yield the correct order of items at that specific point in time.

Examples

use zrx_store::{Queue, StoreIterable, StoreMut};

// Create queue and initial state
let mut queue = Queue::default();
queue.insert("a", 4);
queue.insert("b", 2);
queue.insert("c", 3);
queue.insert("d", 1);

// Create iterator over the queue
for (key, value) in &queue {
    println!("{key}: {value}");
}

Implementations

Source

impl<K, V, S> Queue<K, V, S>
where K: Key, S: Store<K, Item>,

pub fn new() -> Self
where S: Default,

Creates a queue.

Examples
use std::collections::HashMap;
use zrx_store::{Queue, StoreMut};

// Create queue
let mut queue = Queue::<_, _, HashMap<_, _>>::new();
queue.insert("key", 42);
pub fn get_deadline(&self, key: &K) -> Option<Instant>

Returns the deadline of the item identified by the key.

Examples
use std::time::Instant;
use zrx_store::{Queue, StoreMut};

// Create queue and initial state
let mut queue = Queue::default();
queue.insert("key", 42);

// Obtain deadline of item
let deadline = queue.get_deadline(&"key");
assert!(deadline < Some(Instant::now()));
Source

impl<K, V, S> Queue<K, V, S>
where K: Key, S: StoreMut<K, Item>,

pub fn set_deadline(&mut self, key: &K, deadline: Instant) -> Option<Instant>

Sets the deadline of the item identified by the key.

Examples
use std::time::Instant;
use zrx_store::{Queue, StoreMut};

// Create queue and initial state
let mut queue = Queue::default();
queue.insert("key", 42);

// Update deadline of item
queue.set_deadline(&"key", Instant::now());
Source

impl<K, V, S> Queue<K, V, S>
where K: Key, V: Value, S: StoreMut<K, Item> + StoreIterable<K, Item>,

pub fn deadline(&self) -> Option<Instant>

Returns the minimum deadline of all items.

Examples
use std::time::Instant;
use zrx_store::{Queue, StoreMut};

// Create queue and initial state
let mut queue = Queue::default();
queue.insert("key", 42);

// Obtain minimum deadline of all items
let deadline = queue.deadline();
assert!(deadline < Some(Instant::now()));
pub fn take(&mut self) -> Option<(K, V)>

Takes ownership of the next item that is due.

Items are considered to be due if Instant::now has passed the value stored in Item::deadline, which allows to defer processing.

Examples
use zrx_store::{Queue, StoreMut};

// Create queue and initial state
let mut queue = Queue::default();
queue.insert("a", 4);
queue.insert("b", 2);
queue.insert("c", 3);
queue.insert("d", 1);

// Obtain items from queue
while let Some((key, value)) = queue.take() {
    println!("{key}: {value}");
}