pub trait StoreIntoIterator<K, V>: IntoIterator<Item = (K, V)> { }Expand description
Creates an iterator over the items of the store.
pub trait StoreIntoIterator<K, V>: IntoIterator<Item = (K, V)> { }Creates an iterator over the items of the store.